#!/bin/sh
# ----------------------------------------------------------------------------
# /tmp/install.sh - linknx installation
#
# Creation   :  2015-08-26 Tom Schulz, tom_strike(at)gmx(dot)de
# Last Update:  2015-08-27 Tom Schulz
#
# Copyright (c) 2015-08-26 Tom Schulz, tom_strike(at)gmx(dot)de
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
# ----------------------------------------------------------------------------

# include eislib
. /var/install/include/eislib

# set package name
packageName=linknx

package_menu_item='LinKNX'

# ----------------------------------------------------------------------------
# Create user and group
# ----------------------------------------------------------------------------

_uid_gid=${packageName}

__group=$( getent group ${_uid_gid} )

if [ -z "${__group}" ]
then
    /var/install/bin/add-group ${_uid_gid} 76 >/dev/null
fi

__user=$( getent passwd ${_uid_gid} )

if [ -z "${__user}" ]
then
    /var/install/bin/add-user ${_uid_gid} '*' 76 76 "System User for $packageName" \
    /var/lib/${packageName} '' >/dev/null
fi

# ----------------------------------------------------------------------------
# Invalidate password of user
# ----------------------------------------------------------------------------

usermod -L $_uid_gid

# ----------------------------------------------------------------------------
# Create directories
# ----------------------------------------------------------------------------

[ ! -d /var/lib/linknx/persist/log/ ] && mkdir -p /var/lib/linknx/persist/log/

chown -R ${_uid_gid}.${_uid_gid} /var/lib/${packageName}

# ----------------------------------------------------------------------------
# Create kill script
# ----------------------------------------------------------------------------

package_pos=85
package_kill='K'`/usr/bin/expr 100 - $package_pos`${packageName}
ln -sf /etc/init.d/${packageName} /etc/rc2.d/${package_kill}

# ----------------------------------------------------------------------------
# Add menu
# ----------------------------------------------------------------------------

/var/install/bin/add-menu setup.services.menu setup.services.${packageName}.menu "${package_menu_item}"

# ----------------------------------------------------------------------------
# Create default config
# ----------------------------------------------------------------------------

if [ -f "/etc/config.d/${packageName}" ]
then
    update=true
fi

/var/install/config.d/${packageName}-update.sh

# ----------------------------------------------------------------------------
# Start configuration
# ----------------------------------------------------------------------------

if ${update:-false}
then
    /var/install/config.d/${packageName}.sh --quiet
    . /etc/config.d/${packageName}
    if [ "${START_LINKNX}" = "yes" ]
    then
        /etc/init.d/${packageName} start
    fi
fi

exit 0
# ----------------------------------------------------------------------------
# End
# ----------------------------------------------------------------------------
