#!/bin/sh
# ----------------------------------------------------------------------------
# /var/install/config.d/linknx-update.sh - paramater update script
#
# Creation   :  2015-08-26 Tom Schulz, tom_strike(at)gmx(dot)de
# Last Update:  2015-08-27 Tom Schulz
#
# Copyright (c) 2015-08-26 Tom Schulz, tom_strike(at)gmx(dot)de
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
# ----------------------------------------------------------------------------

# include configlib for using printvar
. /var/install/include/configlib

# include eislib
. /var/install/include/eislib

# set packages name
packageName=linknx

# ----------------------------------------------------------------------------
# Set the default values for configuration
# ----------------------------------------------------------------------------
START_LINKNX='no'
LINKNX_CONFIG='/etc/linknx/default.xml'
LINKNX_CONFIG_WRITE='/etc/linknx/default.xml'

# ----------------------------------------------------------------------------
# Read old configuration and rename old variables
# ----------------------------------------------------------------------------
renameOldVariables()
{
    # read old values
    if [ -f /etc/config.d/${packageName} ]
    then
         /var/install/bin/backup-file --quiet ${packageName}
        . /etc/config.d/${packageName}
    fi
}

# ----------------------------------------------------------------------------
# Write config and default files
# ----------------------------------------------------------------------------
makeConfigFile()
{
    internal_conf_file=${1}
    {
    # ------------------------------------------------------------------------
    printgpl -conf ${packageName} "2015-08-26" "Tom Schulz"
    # ------------------------------------------------------------------------

    # ------------------------------------------------------------------------
    printgroup "Basic configuration"
    # ------------------------------------------------------------------------
    printvar "START_LINKNX" "Start LinKNX? Use: yes or no"
    printvar "LINKNX_CONFIG" "read configuration from file (default: /etc/linknx/linknx.xml)"
    printvar "LINKNX_CONFIG_WRITE" "write configuration to file (if no FILE specified, the config file is overwritten)"
    # ------------------------------------------------------------------------
    printend
    # ------------------------------------------------------------------------

    } > ${internal_conf_file}
    # Set rights
    chmod 0600 ${internal_conf_file}
    chown root ${internal_conf_file}
}

# ----------------------------------------------------------------------------
# Create the check.d file
# ----------------------------------------------------------------------------
makeCheckFile()
{

# create file check.d

    printgpl -check ${packageName} '2015-08-15' 'Tom Schulz' >/etc/check.d/${packageName}
    cat >> /etc/check.d/${packageName} <<EOFG

# Variable                OPT_VARIABLE      VARIABLE_N          VALUE
START_LINKNX              -                 -                   YESNO
LINKNX_CONFIG             START_LINKNX      -                   ABS_PATH
LINKNX_CONFIG_WRITE       START_LINKNX        -                 ABS_PATH

EOFG

# Set rights for check.d file
chmod 0600 /etc/check.d/${packageName}
chown root /etc/check.d/${packageName}

#printgpl --check_exp ${packageName} '2015-08-15' 'Tom Schulz' >/etc/check.d/${packageName}.exp
#cat >> /etc/check.d/${packageName}.exp <<EOFG
#
#EOFG

# Set rights for check.exp file
#chmod 0600 /etc/check.d/${packageName}.exp
#chown root /etc/check.d/${packageName}.exp

# printgpl --check_ext ${packageName} '2015-08-23' 'Tom Schulz' >/etc/check.d/${packageName}.ext
# cat >> /etc/check.d/${packageName}.ext <<EOFG
#
# EOFG

# Set rights for check.ext file
# chmod 0600 /etc/check.d/${packageName}.ext
# chown root /etc/check.d/${packageName}.ext
# create file check.ext - not used yet

}

# ----------------------------------------------------------------------------
# Main
# ----------------------------------------------------------------------------
# Write default config file
makeConfigFile /etc/default.d/${packageName}

# Update from old version
renameOldVariables

# Write new config file
makeConfigFile /etc/config.d/${packageName}

# Write check.d file
makeCheckFile

exit 0
# ----------------------------------------------------------------------------
# End
# ----------------------------------------------------------------------------
